<?php

/*
      phpLamma is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
      the Free Software Foundation, either version 3 of the License, or
      (at your option) any later version.

      phpLamma is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
      GNU General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with this program.  If not, see <https://www.gnu.org/licenses/>.

     company/organization: MR_ROBOT_COMPUTERS_REPAIR
     Country: Italy
     City: Barga (LU)
     website: mrrobotcomputers.hopto.org
     mail address: mrrobotcomputersrepair@gmail.com

*/


class phpLamma
{

	private $url="http://www.lamma.rete.toscana.it/previ/ita/xml/comuni_web/dati/";
	private $version="phpLamma v0.1";

	const DAY="giorno";
	const MORNING="mattina";
	const AFTERNOON="pomeriggio";
	const EVENING="sera";
	const NIGHT="notte";

	const TEMP_MIN="min";
	const TEMP_MAX="max";
	const TEMP_REAL="";
	const TEMP_PERC="perc";

	const HYDRO_RISK="idraulico";
	const GEO_HYDRO_RISK="idrogeologico";
	const THUNDERSTORM_RISK="temporali";
	const WIND_RISK="vento";
	const SNOW_RISK="neve";
	const ICE_RISK="ghiaccio";

	private $city_list=array();
	private $your_city="";
	private $previsions=array(); 

	function _dataURL()
	{
		return $this->url;
	}

	function getCityList() //ok
	{
		$i=0;
		try{
			$cityListUrl="http://www.lamma.rete.toscana.it/previ/ita/xml/lista_comuni.xml";
			$xml=simplexml_load_file($cityListUrl);
			foreach($xml as $city)
			{
				@array_push($this->city_list,$xml->link[$i]->title[0]);
				$i++;
			}
			return $this->city_list;
		}
		catch(Exception $e){return false;}
	}

	function selectCity($city) //ok
	{
		try{
			$cityURL="http://www.lamma.rete.toscana.it/previ/ita/xml/comuni_web/dati/".strtolower(str_replace(" ","",$city)).".xml";
			$xml=simplexml_load_file($cityURL);
			$this->your_city=$xml;
			return $this->your_city;
		}
		catch(Exception $e) {return false;}
	}

	function name($city) //ok
	{
		try{
			$name=$city->comune[0];
			return $name;
		}
		catch(Exception $e) {return false;}
	}

	function getUnixTimestamp($city) //ok
	{
		try{
			$timestamp=$city->time_ms[0];
			return $timestamp;
		}
		catch(Exception $e) {return false;}
	}

	function lastUpdate($city)  //ok
	{
		try{
			$lastUpdate=$city->aggiornamento[0];
			return $lastUpdate;
		}
		catch(Exception $e) {return false;}
	}

	function sunrise($city) //ok
	{
		try{
			$sunrise=$city->almanacco->sole_sorge[0];
			return $sunrise;
		}
		catch(Exception $e){return false;}
	}

	function sunset($city) //ok
	{
		try{
			$sunset=$city->almanacco->sole_tramonta[0];
			return $sunset;
		}
		catch(Exception $e) {return false;}
	}

	function sun_height($city) //ok
	{
		try{
			$sun_height=$city->almanacco->sole_altezza[0];
			return $sun_height;
		}
		catch(Exception $e) {return false;}
	}

	function max_sun_hour($city) //ok
	{
		try{
			$max_sun_hour=$city->almanacco->ora_altezza[0];
			return $max_sun_hour;
		}
		catch(Exception $e) {return false;}
	}

	function moon_rises($city) //ok
	{
		try{
			$moon_rises=$city->almanacco->luna_sorge[0];
			return $moon_rises;
		}
		catch(Exception $e) {return false;}
	}

	function moon_sets($city) //ok
	{
		try{
			$moon_sets=$city->almanacco->luna_tramonta[0];
			return $moon_sets;
		}
		catch(Exception $e) {return false;}
	}

	function getPrevisions($city) //ok
	{
		try{
			$this->previsions=$city->previsione;
			return $this->previsions;
		}
		catch(Exception $e) { return false;}
	}

	function getDayByIdday($idday,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday']) return $prev['datadescr'] ;
			}
		}
		catch(Exception $e) {return false;}
	}

	function getWeather($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$weather=$prev->simbolo['descr'];
					return $weather;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getWeatherStat_wind($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$weather=$prev->simbolo[1]['descr'];
					return $weather;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getWeatherStat_temps($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$temps=$prev->simbolo[2]['descr'];
					return $temps;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getUV($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$uv=$prev->uv;
					return $uv;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getTemps($idday,$time,$temp_type,$prevs) //ok
	{

		if($time == self::DAY && $temp_type == self::TEMP_REAL) return "<b>Warning: self::DAY + self::REAL is not valid data schema. Use self::TEMP_MIN or self::TEMP_MAX constants instead</b>";
		if($time == self::DAY && $temp_type == self::TEMP_PERC) return "<b>Warning: self::DAY + self::PERC is not valid data schema. Use self::TEMP_MIN or self::TEMP_MAX constants instead</b>";

		if($time == self::MORNING && $temp_type == self::TEMP_MIN || $time == self::MORNING && $temp_type == self::TEMP_MAX) return "<b>Warning: self::MORNING + self::MIN / self::MAX is not valid data schema. Use self::TEMP_REAL or self::TEMP_PERC constants instead</b>";
		if($time == self::AFTERNOON && $temp_type == self::TEMP_MIN || $time == self::AFTERNOON && $temp_type == self::TEMP_MAX) return "<b>Warning: self::AFTERNOON + self::MIN / self::MAX is not valid data schema. Use self::TEMP_REAL or self::TEMP_PERC constants instead</b>";
		if($time == self::EVENING && $temp_type == self::TEMP_MIN || $time == self::EVENING && $temp_type == self::TEMP_MAX) return "<b>Warning: self::EVENING + self::MIN / self::MAX is not valid data schema. Use self::TEMP_REAL or self::TEMP_PERC constants instead</b>";
		if($time == self::NIGHT && $temp_type == self::TEMP_MIN || $time == self::NIGHT && $temp_type == self::TEMP_MAX) return "<b>Warning: self::NIGHT + self::MIN / self::MAX is not valid data schema. Use self::TEMP_REAL or self::TEMP_PERC constants instead</b>";

		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					if($temp_type == "min") {
						if($prev->temp[0]['temp_type'] == $temp_type)	 $temp=$prev->temp[0];
						else 						 {return false;}
					}
					if($temp_type == "max"){
						if($prev->temp[1]['temp_type'] == $temp_type)    $temp=$prev->temp[1];
						else						 {return false;}
					}
					if($temp_type == ""){
						if($prev->temp[0]['temp_type'] == $temp_type)    $temp=$prev->temp[0];
						else						 {return false;}
					}
					if($temp_type == "perc"){
						if($prev->temp[1]['temp_type'] == $temp_type)	 $temp=$prev->temp[1];
						else						 {return false;}
					}
					return $temp;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getInversion($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$inversion=$prev->inversione;
					return $inversion;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getHumidity($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$humidity=$prev->um;
					return $humidity;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getRainProbability($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$rain_prob=$prev->prob_rain;
					return $rain_prob;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getSnowLevel($idday,$time,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $time == $prev['ora'])
				{
					$snow_lv=$prev->quota_neve;
					return $snow_lv;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getAlert($idday,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $prev['ora'] == self::DAY)
				{
					$alert=$prev->allerta['value'];
					return $alert;
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function getRisk($idday,$risk_type,$prevs) //ok
	{
		try{
			foreach($prevs as $prev)
			{
				if($idday == $prev['idday'] && $prev['ora'] == self::DAY)
				{
					if($risk_type == self::HYDRO_RISK) return $prev->rischio[0]['value'];
					if($risk_type == self::GEO_HYDRO_RISK) return $prev->rischio[1]['value'];
					if($risk_type == self::THUNDERSTORM_RISK) return $prev->rischio[2]['value'];
					if($risk_type == self::WIND_RISK) return $prev->rischio[3]['value'];
					if($risk_type == self::SNOW_RISK) return $prev->rischio[4]['value'];
					if($risk_type == self::ICE_RISK) return $prev->rischio[5]['value'];
				}
			}
		}
		catch(Exception $e) {return false;}
	}

	function version()
	{
		return $this->version;
	}

}

?>
